@@ -4,7 +4,8 @@ from breathe.renderer.sphinxrenderer import setup as renderer_setup
 
 from sphinx.application import Sphinx
 
-__version__ = '4.30.0'
+# Keep in sync with setup.py __version__
+__version__ = "4.32.0"
 
 
 def setup(app: Sphinx):
@@ -12,8 +13,4 @@ def setup(app: Sphinx):
     file_state_cache_setup(app)
     renderer_setup(app)
 
-    return {
-        'version': __version__,
-        'parallel_read_safe': True,
-        'parallel_write_safe': True
-    }
+    return {"version": __version__, "parallel_read_safe": True, "parallel_write_safe": True}
